@@ -8,6 +8,8 @@
  *
  * Minor changes Copyright Kris Thielemans 2011:
  *  make dicomdict('get') and dicomdict('set',filename) work properly and add doc-string
+ *
+ * Minor changes Copyright John Donoghue 2018-2019:
  * 
  * The GNU Octave dicom package is free software: you can redistribute 
  * it and/or modify it under the terms of the GNU General Public 
@@ -26,13 +28,16 @@
 
 #include "octave/oct.h"
 #include "octave/octave.h"
-#include "octave/interpreter.h"
 #include "octave/load-path.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#if HAVE_OCTAVE_LOAD_PATH == 1
+  #include "octave/interpreter.h"
+#endif
+
 #include "gdcmDict.h"
 #include "gdcmVR.h"
 #include "gdcmVM.h"
@@ -74,7 +79,7 @@ In this case, the dictionary file @var{dictionary_name} can be anywhere in the p
 @end deftypefn \n") {
 	octave_value_list retval;  // create object to store return values
 	if (args.length()>2 || args.length()<1) {
-		error(QUOTED(OCT_FN_NAME)": takes 1 or 2 arguments, got %i.",args.length ());
+		error(QUOTED(OCT_FN_NAME)": takes 1 or 2 arguments, got %i.", (int)args.length ());
 		return retval; 
 	}
 	if (! args(0).is_string ()) {
@@ -101,7 +106,7 @@ In this case, the dictionary file @var{dictionary_name} can be anywhere in the p
 			
 			return retval;
 		} else {
-			error(QUOTED(OCT_FN_NAME)": single arg must either be 'get' or 'factory'.",args.length ());
+			error(QUOTED(OCT_FN_NAME)": single arg must either be 'get' or 'factory'.");
 			return retval; 
 		}
 	}
@@ -113,7 +118,7 @@ In this case, the dictionary file @var{dictionary_name} can be anywhere in the p
 	}
 	std::string arg1str = arg1mat.row_as_string (0);
 	if (arg0str != std::string("set")) {
-		error(QUOTED(OCT_FN_NAME)": when 2 args are given, the first must be 'set'.",args.length ());
+		error(QUOTED(OCT_FN_NAME)": when 2 args are given, the first must be 'set'.");
 		return retval; 
 	}
 	load_dicom_dict(arg1str.c_str());
@@ -326,7 +331,7 @@ void load_dicom_dict(const char * filename) {
 		gdcm::VM vm = vmMap[tvm] ;
 
 		// Warn if keyword cannot be used in octave
-		if ( ! valid_identifier(key) ) {
+		if ( ! OCTAVE__VALID_IDENTIFIER (key) ) {
 			std::cerr << "WARNING: Invalid identifier '" << key << "'" << std::endl << std::flush ;
 		}
 
