@@ -98,13 +98,13 @@ Write a DICOM format file to @var{filename}.\n\
 	if (3 > args.length()) { // no metadata supplied, need to make some
 		try {
 			genMinimalMetaData(&w, file);
-		} catch (std::exception) {
+		} catch (std::exception&) {
 			return retval ;
 		}
 	} else { // 3rd arg should be struct to turn into metadata
 		try {
 			struct2metadata(&w, file, args(2), trial, 0 /* depth of indent for SQ nesting */);
-		} catch (std::exception) {
+		} catch (std::exception&) {
 			return retval ;
 		}
 	}
@@ -113,7 +113,7 @@ Write a DICOM format file to @var{filename}.\n\
 		octave_value pixval = args(0);
 		try {
 			octaveVal2dicomImage(&w, &pixval);
-		} catch (std::exception) {
+		} catch (std::exception&) {
 			return retval ;
 		}
 	}
@@ -173,7 +173,7 @@ void struct2metadata(gdcm::ImageWriter *w, gdcm::File *file, const octave_value
 		bool handled ;
 		try {
 			value2element(&de, &cell(0), &tag, keyword, trial, &handled, sequenceDepth);
-		} catch (std::exception) {
+		} catch (std::exception&) {
 			return;
 		}
 		if (handled) {
@@ -187,7 +187,7 @@ void struct2metadata(gdcm::ImageWriter *w, gdcm::File *file, const octave_value
 	}
 	if (skipped>0) {
 		// TODO: this does not count elements nested in SQs
-		warning(QUOTED(OCT_FN_NAME)": skipped %i keyword-value pairs. not in dictionary\n",skipped);
+		warning(QUOTED(OCT_FN_NAME)": skipped %u keyword-value pairs. not in dictionary\n",skipped);
 	}
 	// TODO are these set functions taking a copy? if they take a reference to objects that are about to go out of scope, we have a problem
 	file->SetDataSet((gdcm::DataSet &)ds);
@@ -213,7 +213,7 @@ void structarray2sequence(gdcm::SequenceOfItems & sq, octave_map * om, bool tria
 			bool handled;
 			try {
 				value2element(&de, &(subom.contents(subit)(0)), &tag, subkeyword, trial, &handled, sequenceDepth);
-			} catch (std::exception) {
+			} catch (std::exception&) {
 				return;
 			}
 			if (!handled) {
@@ -310,7 +310,7 @@ void value2element (gdcm::DataElement * de, const octave_value * ov, gdcm::Tag *
 		gdcm::SmartPointer<gdcm::SequenceOfItems> sq = new gdcm::SequenceOfItems();
 		try {
 			structarray2sequence(*sq, &subom, trial, ++sequenceDepth) ;
-		} catch (std::exception) {
+		} catch (std::exception&) {
 			return;
 		}
 		sequenceDepth--;
@@ -323,7 +323,7 @@ void value2element (gdcm::DataElement * de, const octave_value * ov, gdcm::Tag *
 // TODO set HighBit etc using octave class. or cast pixel data using metadata, or just give error if they don't agree
 void octaveVal2dicomImage(gdcm::ImageWriter *w, octave_value *pixval) {
 	if (pixval->ndims() != 2) {
-		error(QUOTED(OCT_FN_NAME)": image has %i dimensions. not implemented. ", pixval->ndims());
+		error(QUOTED(OCT_FN_NAME)": image has %i dimensions. not implemented. ", (int)pixval->ndims());
 		throw std::exception();
 	}
 	
@@ -381,7 +381,7 @@ void octaveVal2dicomImage(gdcm::ImageWriter *w, octave_value *pixval) {
 	unsigned long buflen=im->GetBufferLength();
 	if (buflen != pixval->byte_size()) { 
 		delete [] matbuf;
-		error(QUOTED(OCT_FN_NAME)": prepared DICOM buffer size(%i) does not match Octave array buffer size(%i).",buflen,pixval->byte_size());
+		error(QUOTED(OCT_FN_NAME)": prepared DICOM buffer size(%lu) does not match Octave array buffer size(%i).",buflen, (int)pixval->byte_size());
 		throw std::exception() ;
 	}
 
